@@ -235,26 +235,28 @@ def get_actor_output_ports(actor: Actor, actor_desc: json) -> list:
 '''
 system_parameters = ["core_num", "partition", "parallel_num", "ntask"]
 
+
 def get_actor_params(actor: Actor, actor_desc: json) -> Args:
     params_json = dict_utils.get_property_value(actor_desc, 'parameters', [])
     args = Args()
     for param in params_json:
         # type
         param_type = param.get('type')
-        # param的类型
+        # param的变量名
         param_variable = param.get('variable')
-        # param的名称
+        # param显示的名称
         param_name = param.get('name')
-        # param的值
+        # param显示的值
         param_value = param.get('value')
-        # description
+        # param显示的描述
         param_description = param.get('description')
         # port依赖的上游actor
         module = str(config.PARAM_PATH)
         param_module = importlib.import_module(module)
         param_class = getattr(param_module, param_type)
         param = param_class(name=param_name, description=param_description, value=param_value)
-        setattr(args, param_variable, param)
+        setattr(args, param_variable, param_value)
+        setattr(args, param_variable+"_object", param)
     return args
 
 
@@ -266,15 +268,16 @@ if __name__ == '__main__':
     parser.add_argument('--redis_host', type=str, default=None)
     parser.add_argument('--flow_manager_server', type=str, default=None)
     parser.add_argument('--parallel_index', type=int, default=None)
-    args = parser.parse_args()
+    actor_args = parser.parse_args()
     # actor_desc = 'eyJuYW1lIjogIlNpbmsiLCAidmVyc2lvbiI6ICIxLjAiLCAicnVudGltZSI6ICJweXRob24zIiwgImFjdG9yX2ZpbGUiOiAiTXlTaW5rQWN0b3IucHkiLCAiYWN0b3JfY2xhc3MiOiAiTXlTaW5rQWN0b3IiLCAiZXhlY19kZXBlbmRzIjogW10sICJpbnB1dF9wb3J0cyI6IFt7Im5hbWUiOiAiaW50YWtlIiwgImNsYXNzIjogIlRleHRJbnB1dFBvcnQiLCAiY29ubmVjdCI6IFt7ImFjdG9yIjogIlBhcmFsbGVsIiwgInBvcnQiOiAic3VjY2VzcyJ9XX1dLCAicGFyYW1ldGVycyI6IFt7Im5hbWUiOiAiY3B1X2NvdW50IiwgImNsYXNzIjogIkludGVnZXJQYXJhbWV0ZXIiLCAiZGVmYXVsdCI6IDEsICJ2YWx1ZSI6IDF9LCB7Im5hbWUiOiAicGFydGl0aW9uIiwgImNsYXNzIjogIlN0cmluZ1BhcmFtZXRlciIsICJkZWZhdWx0IjogImMtNC0xIiwgInZhbHVlOiI6ICJjLTQtMSJ9XX0_'
     # flow_manager_server = 'http://192.168.110.20:7020'
-    actor_desc = args.actor_desc
-    flow_manager_server = args.flow_manager_server
-    redis_host = args.redis_host
-    flow_depth = args.flow_depth
-    actor_level = args.actor_level
-    parallel_index = args.parallel_index
+    actor_desc = actor_args.actor_desc
+    flow_manager_server = actor_args.flow_manager_server
+    redis_host = actor_args.redis_host
+    flow_depth = actor_args.flow_depth
+    actor_level = actor_args.actor_level
+    parallel_index = actor_args.parallel_index
+
     pool = ConnectionPool(max_connections=10, host=redis_host, port=6379, password='123456')
     redis_client = StrictRedis(connection_pool=pool)
     state_utils = FlowStateUtils(redis_client)
@@ -284,14 +287,14 @@ if __name__ == '__main__':
     actor_file = actor_json.get('actor_file')
     actor_class_name = actor_json.get('actor_class')
     current_actor_name = actor_json.get('name')
-    input_ports = actor_json.get('input_ports', [])
-    output_ports = actor_json.get('output_ports', [])
+    # input_ports = actor_json.get('input_ports', [])
+    # output_ports = actor_json.get('output_ports', [])
     actor_module = importlib.import_module(config.CUSTOMIZE_ACTOR_PATH + actor_class_name)
     actor_class = getattr(actor_module, actor_class_name)
     actor = actor_class()
     # set actor 变量参数
     params = get_actor_params(actor, actor_json)
-    actor.set_args(params)
+    actor.args = params
     # TODO get_set_param,get_set_runtime_param
     input_ports = get_actor_input_ports(actor, actor_json)
     output_ports = get_actor_output_ports(actor, actor_json)
