@@ -1,7 +1,6 @@
-from cloudam_stream.core.actors import ParallelComputeActor
-from cloudam_stream.core.ports.outputports import TextOutputPort
-
-from cloudam_stream.core.ports.inputports import TextInputPort
+from core.actors import ParallelComputeActor
+from core.ports.inputports import TextInputPort
+from core.ports.outputports import TextOutputPort
 
 
 class MyParallelComputeActor(ParallelComputeActor):
