@@ -1,8 +1,8 @@
-from cloudam_stream.core.actors import SourceActor
-from cloudam_stream.core.ports.outputports import TextOutputPort
+from core.actors import SourceActor
+from core.ports.outputports import TextOutputPort
 
-from cloudam_stream.core.parameters import FileParameter
-from cloudam_stream.core.constants import config
+from core.parameters import FileParameter
+from core.constants import config
 import pickle
 
 
